/*

*/

import java.awt.Color;
import java.awt.Point;
import java.awt.Graphics;
import java.awt.Dimension;
import javax.swing.JPanel;

/**
   This class has the responsibility of updating
   what we see (view) in the graphics panel.

   The paintComponent() method will be called by the
   Event Dispatch Thread (the "GUI thread") whenever
   the GUI system decides that this panel needs to be
   redrawn.

   An instance of this class needs access to an object
   that holds the current state of out graphics program.
*/
@SuppressWarnings("serial")
public class CirclePanel extends JPanel
{
   private final CircleState cs;

   public CirclePanel(CircleState cs)
   {
      this.cs = cs;
      setPreferredSize(new Dimension(600, 600));
   }

   @Override
   public void paintComponent(Graphics g)
   {
      super.paintComponent(g); // Call JPanel's version. Try commenting this out.

      g.setColor(Color.white);
      for (Point p : cs.trail)
      {
         g.fillOval(p.x, p.y, cs.diameter, cs.diameter); // redraw every old disk
     }

      g.setColor(Color.red);
      g.fillOval(cs.xNew, cs.yNew, cs.diameter, cs.diameter); // draw new disk
      cs.trail.add(new Point(cs.xNew, cs.yNew));
   }
}
